@@ -8,10 +8,9 @@ import logging
 import typer
 
 from dvc.version import __version__
-from dvc.app.cli.commands import config, database, sql
-
-# Set default logging to INFO
-logging.root.setLevel(logging.INFO)
+from dvc.app.cli.commands import config, database
+from dvc.core.logger import SetRootLoggingLevel
+from dvc.core.config import ConfigDefault
 
 DOCUMENTATION_URL = "https://python-database-version-control.readthedocs.io/en/latest/"
 EPILOG_TXT = f"Doc: {DOCUMENTATION_URL}"
@@ -24,11 +23,13 @@ app = typer.Typer(
 )
 app.add_typer(config.app, name='cfg', help="Config related subcommands")
 app.add_typer(database.app, name='db', help="Database related subcommands")
-app.add_typer(sql.app, name='sql', help="SQL files related subcommands")
 
 
 @app.command()
-def version():
+@SetRootLoggingLevel
+def version(
+        config_file_path: str = typer.Option(str(ConfigDefault.VAL__FILE_PATH), help="path to config file"),
+):
     """
     Show CLI version
     """
